/*========================================================================================================
 * Arcade1StickDrive.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to drive the robot using joysticks in a arcade
 * drive mode.
 *
 * Thus, the left axis will control speed (throttle) and the right axis will control direction
 * (steering). The speed control (throttle) will get a cubic profile while the steer control
 * will be direct (linear).
 *
 * Then, the left and right speeds are set by using the arcade drive equations where
 * the left side adds the steer value to the throttle value and the right side
 * subtracts the steer value from the trottle.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// Team 302 includes
#include <Arcade1StickDrive.h>      // This class
#include <ArcadeDrive.h>            // Base class

//--------------------------------------------------------------------
// Method:      Arcade1StickDrive <<constructor>>
// Description: This method creates and initializes the objects
//--------------------------------------------------------------------
Arcade1StickDrive::Arcade1StickDrive() : ArcadeDrive()
{
    Init();
}

//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void Arcade1StickDrive::Init()
{
    CommonInit( ARCADE_DRIVE_1STICK_THROTTLE, ARCADE_DRIVE_1STICK_STEER );
}


//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* Arcade1StickDrive::GetIdentifier() const
{
    return "Arcade 1 Stick Drive";
}
