/*========================================================================================================
 * CompetitionBotMap.h
 *========================================================================================================
 *
 * File Description:
 *
 * This is for the Competition bot.
 *
 * This defines the identifiers (e.g. what is the CAN ID of a particular Talon) for the
 * various motor controllers, sensors, etc.  It provides a constant that defines how the robot
 * is wired, so that if wiring changes, the constants in this file can be updated without impacting
 * the rest of the code.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// TODO:  This is currently just a copy of the software bot, need to update to the competition bot

#ifndef SRC_COMPETITIONBOTMAP_H_
#define SRC_COMPETITIONBOTMAP_H_

	const int ROBOT_CONFIGURATION			= COMPETITION_BOT;

    //==========================================================================================
    // USB CONTROLLER PORTS
    //==========================================================================================
    const int DRIVER_CONTROLLER             = 0;
    const int OPERATOR_CONTROLLER           = 1;

    //==========================================================================================
    // CAN PORTS
    //==========================================================================================
    const int FRONT_LEFT_DRIVE_MOTOR                    = 1;
    const int FRONT_RIGHT_DRIVE_MOTOR                   = 4;
    const int BACK_LEFT_DRIVE_MOTOR                     = 2;
    const int BACK_RIGHT_DRIVE_MOTOR                    = 3;


    //==========================================================================================
    // Drive TALON (Motor) inversion settings
    //==========================================================================================
    // Right side of the robot is inverted so that the motors all go the same way
    const bool IS_FRONT_LEFT_DRIVE_MOTOR_INVERTED   = false;
    const bool IS_FRONT_RIGHT_DRIVE_MOTOR_INVERTED  = true;
    const bool IS_BACK_LEFT_DRIVE_MOTOR_INVERTED    = false;
    const bool IS_BACK_RIGHT_DRIVE_MOTOR_INVERTED   = true;

    //==========================================================================================
    // Drive Encoder conversion rates to convert from counts to feet and feet per second
    //==========================================================================================
    const float ENCODER_DISTANCE_CONVERSION = 0.0010908307638889; // encoder counts to feet
    const float ENCODER_VELOCITY_CONVERSION = 0.0109083076388889; // encoder counts per 0.1 sec to feet per second


    //==========================================================================================
    // Analog Input Devices
    //==========================================================================================
    const int ANALOG_SENSOR_PORT  = 3;

    //==========================================================================================
    // Digital Input/Output PORTS
    //==========================================================================================
    const int DIGITAL_INPUT_SENSOR_PORT  = 0;


    //==========================================================================================
    // PWM Output Ports
    //==========================================================================================


    //==========================================================================================
    // PNEUMATIC SOLENOID Ports
    //==========================================================================================




#endif /* SRC_COMPETITIONBOTMAP_H_ */
