/*========================================================================================================
 * DriveToDistance.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to drive the robot a specified distance.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// Team 302 includes
#include <DriveToDistance.h>        // This class
#include <RunMotorsDrive.h>         // Parent Class
#include <IChassis.h>               // Class the control the drive motors


//--------------------------------------------------------------------
// Method:      DriveToDistance <<constructor>>
// Description: This method creates/intializes the object.
//--------------------------------------------------------------------
DriveToDistance::DriveToDistance
(
    float   distance            // <I> - distance to drive in feet
) : RunMotorsDrive( 0.5 ),
    m_targetDistance( distance ),
    m_slowDownDistance( 0.75*distance )
{
    Init();
}

//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void DriveToDistance::Init()
{
    IChassis* chassis = GetChassis();
    chassis->SetBrakeMode();
    chassis->ResetDistance();
    ChangeSpeed( 0.5 );
}

//--------------------------------------------------------------------
// Method:      HasTarget
// Description: This indicates if this drive mode has a target
// Returns:     true = has a target (distance)
//--------------------------------------------------------------------
bool DriveToDistance::HasTarget() const
{
    return true;
}


//--------------------------------------------------------------------
// Method:      SetTarget
// Description: This sets the target for the drive class.
// Returns:     void
//--------------------------------------------------------------------
void DriveToDistance::SetTarget
(
    float   target
)
{
    m_targetDistance = target;
}

//--------------------------------------------------------------------
// Method:      DrivePeriodic
// Description: This method will be called during the periodic loop
//              to drive the robot a specified distance.
// Returns:     true  = reached the specified distance
//              false = hasn't reached the specified distance
//--------------------------------------------------------------------
bool DriveToDistance::DrivePeriodic() const
{
    bool atTarget = false;
    // Get the average distance the robot has travelled
    IChassis* chassis   = GetChassis();
    float leftDistance  = chassis->GetLeftSideDistance();
    float rightDistance = chassis->GetRightSideDistance();
    float avgDistance = ( leftDistance + rightDistance ) / 2.0;

    // TODO:    Implement the following:
    //
    // Set the speed based on the following conditions:
    // 1) Haven't reached the slow down zone (approach zone) -- main speed
    // 2) Reached approach zone -- slow down
    // 3) Reached target -- stop
    //
    //  Will we go past the target?  Do we need to back up?
    //  NOTE:  there are better ways that will gradually slow down that
    //         we will learn later.

    float speed = 0.0;

    ChangeSpeed( speed );
    return atTarget;
}

//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* DriveToDistance::GetIdentifier() const
{
    return "Drive to Distance";
}


//--------------------------------------------------------------------
// Method:      ~DriveToDistance  <<destructor>>
// Description: Clean up memory.
//--------------------------------------------------------------------
DriveToDistance::~DriveToDistance()
{
}

