/*========================================================================================================
 * IDrive.h
 *========================================================================================================
 *
 * File Description:
 *
 * This is an interface to the various drive test commands
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/
#ifndef SRC_IDRIVE_H_
#define SRC_IDRIVE_H_

class IDrive
{

    public:
        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        virtual void Init() = 0;

        //--------------------------------------------------------------------
        // Method:      DrivePeriodic
        // Description: This method will be called during the periodic loop
        //              to drive the robot.
        // Returns:     true  = completed this task
        //              false = still running this task
        //--------------------------------------------------------------------
        virtual bool DrivePeriodic() const = 0;

        //--------------------------------------------------------------------
        // Method:      HasTarget
        // Description: This indicates if this drive mode has a target
        //              such as time, distance, etc.
        // Returns:     true  = has a target
        //              false = doesn't have a target
        //--------------------------------------------------------------------
        virtual bool HasTarget() const = 0;

        //--------------------------------------------------------------------
        // Method:      SetTarget
        // Description: This sets the target for the drive class.
        // Returns:     void
        //--------------------------------------------------------------------
        virtual void SetTarget
        (
            float   target
        ) = 0;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        virtual const char* GetIdentifier() const = 0;


    protected:
        IDrive() = default;             // default constructor used by the implementors of this interface
        virtual ~IDrive() = default;    // default destructors used by implementors of this interface

    private:

        // Default methods we don't want the compiler to implement for us
        IDrive( const IDrive& ) = delete;
        IDrive& operator= ( const IDrive& ) = delete;
        explicit IDrive( IDrive* other ) = delete;

};


#endif /* SRC_IDRIVE_H_ */
