/*========================================================================================================
 * IDriveFactory.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This creates the IDrive classes.  It will retain what it has created, so that it only will create one
 * of any given type of IDrive.
 *
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

//  Team 302 includes
#include <IDriveFactory.h>			// This class

#include <IDrive.h>					
#include <AnalogInputDrive.h>
#include <ArcadeDrive.h>
#include <Arcade1StickDrive.h>
#include <DigitalInputDrive.h>
#include <DriveToDistance.h>
#include <NoMoveDrive.h>
#include <RunMotorsDrive.h>
#include <TankDrive.h>
#include <TimedDrive.h>
#include <TriggerDrive.h>


IDriveFactory* IDriveFactory::m_instance = nullptr;	// initialize the instance variable to nullptr

//----------------------------------------------------------------------------------
// Method:		GetInstance
// Description:	If there isn't an instance of desired IDrive class, create it.
//				Otherwise, hand out the single instance.
// Returns:		IDriveFactory*	Drive class
//----------------------------------------------------------------------------------
IDriveFactory*	IDriveFactory::GetInstance()

{
	if ( IDriveFactory::m_instance == nullptr )
	{
		IDriveFactory::m_instance = new IDriveFactory();
	}
	return IDriveFactory::m_instance;
}

//----------------------------------------------------------------------------------
// Method:		GetIDrive
// Description:	If there isn't an instance of desired IDrive class, create it.
//				Otherwise, hand out the single instance.
// Returns:		IDrive*	Drive class
//----------------------------------------------------------------------------------
IDrive*	IDriveFactory::GetIDrive
(
	IDRIVE_IDENTIFIER		type, 		// <I> - type of drive desired
	float					target		// <I> - if the drive type has a target (distance,
										//       time, etc.), this is that value.
)
{
	IDrive* drive = m_idrive[ type ];
	if ( drive == nullptr )
	{
		switch ( type )
		{
			case ANALOG_INPUT_DRIVE:
				drive = new AnalogInputDrive();
				m_idrive[type] = drive;
				break;
			
			case ARCADE_DRIVE:
				drive = new ArcadeDrive();
				m_idrive[type] = drive;
				break;
			
			case ARCADE_1STICK_DRIVE:
				drive = new Arcade1StickDrive();
				m_idrive[type] = drive;
				break;
			
			case DIGITAL_INPUT_DRIVE:
				drive = new DigitalInputDrive();
				m_idrive[type] = drive;
				break;
			
			case DRIVE_TO_DISTANCE:
				drive = new DriveToDistance( target );
				m_idrive[type] = drive;
				break;
			
			case NO_MOVE_DRIVE:
				drive = new NoMoveDrive();
				m_idrive[type] = drive;
				break;
			
			case RUN_MOTORS_DRIVE:
				drive = new RunMotorsDrive( target );
				m_idrive[type] = drive;
				break;
			
			case TANK_DRIVE:
				drive = new TankDrive();
				m_idrive[type] = drive;
				break;
			
			case TIMED_DRIVE:
				drive = new TimedDrive( target );
				m_idrive[type] = drive;
				break;
			
			case TRIGGER_DRIVE:
				drive = new TriggerDrive();
				m_idrive[type] = drive;
				break;
			
			default:
			break;
			
		}
	}
	else
	{
		if ( drive->HasTarget() )
		{
			drive->SetTarget( target );
		}
	}
	return drive;
}
//--------------------------------------------------------------------
// Method:      IDriveFactory <<constructor>>
// Description: This method creates and initializes the objects
//--------------------------------------------------------------------
IDriveFactory::IDriveFactory()      // constructor
{
	m_idrive.resize( MAX_DRIVE_MODES );
	std::fill( m_idrive.begin(), m_idrive.end(), nullptr );	
}
