/*========================================================================================================
 * IDriveFactory.h
 *========================================================================================================
 *
 * File Description:
 *
 * This creates the IDrive classes.  It will retain what it has created, so that it only will create one
 * of any given type of IDrive.
 *
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

#ifndef SRC_IDRIVEFACTORY_H_
#define SRC_IDRIVEFACTORY_H_


//  Team 302 includes
#include <IDrive.h>
#include <AnalogInputDrive.h>
#include <ArcadeDrive.h>
#include <Arcade1StickDrive.h>
#include <DigitalInputDrive.h>
#include <DriveToDistance.h>
#include <NoMoveDrive.h>
#include <RunMotorsDrive.h>
#include <TankDrive.h>
#include <TimedDrive.h>
#include <TriggerDrive.h>


enum IDRIVE_IDENTIFIER
{
	ANALOG_INPUT_DRIVE,
    ARCADE_DRIVE,
    ARCADE_1STICK_DRIVE,
    DIGITAL_INPUT_DRIVE,    
    DRIVE_TO_DISTANCE,
	NO_MOVE_DRIVE,
	RUN_MOTORS_DRIVE,
    TANK_DRIVE,
	TIMED_DRIVE,
	TRIGGER_DRIVE,
    MAX_DRIVE_MODES
};

class IDriveFactory
{
	public:
	//----------------------------------------------------------------------------------
	// Method:		GetInstance
	// Description:	If there isn't an instance of desired IDrive class, create it.
	//				Otherwise, hand out the single instance.
	// Returns:		IDrive*	Drive class
	//----------------------------------------------------------------------------------
	static IDriveFactory*	GetInstance();

	//----------------------------------------------------------------------------------
	// Method:		GetIDrive
	// Description:	If there isn't an instance of desired IDrive class, create it.
	//				Otherwise, hand out the single instance.
	// Returns:		IDrive*	Drive class
	//----------------------------------------------------------------------------------
	IDrive*	GetIDrive
	(
		IDRIVE_IDENTIFIER		type, 		// <I> - type of drive desired
		float					target		// <I> - if the drive type has a target (distance,
											//       time, etc.), this is that value.
	);

	protected:

	private:
		//--------------------------------------------------------------------
		// Method:      IDriveFactory <<constructor>>
		// Description: This method creates and initializes the objects
		//--------------------------------------------------------------------
		IDriveFactory();      // constructor
	
		//--------------------------------------------------------------------
		// Method:      ~IDriveFactory <<destructor>>
		// Description: This method is called to delete these objects
		//--------------------------------------------------------------------
		virtual ~IDriveFactory() = default; // destructor

		// Attributes
		static IDriveFactory* 		m_instance;		// the factory

		std::vector<IDrive*>    	m_idrive;  		// drives that have been created

        // Default methods we don't want the compiler to implement for us
        IDriveFactory( const IDriveFactory& ) = delete;
        IDriveFactory& operator= ( const IDriveFactory& ) = delete;
        explicit IDriveFactory( IDriveFactory* other ) = delete;


};

#endif /* SRC_IDRIVEFACTORY_H_ */
