/*========================================================================================================
 * TimedDrive.h
 *========================================================================================================
 *
 * File Description:
 *
 * This class extends the RunMotorsDrive class that runs the drive motors for a specified amount of time.
 *
 * This class converts the specified amount of time into a number of loops.  Then it counts the number
 * of times it gets called during its periodic method to determine elapsed time.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// Team 302 includes
#include <TimedDrive.h>             // This class
#include <RunMotorsDrive.h>         // Parent Class

//--------------------------------------------------------------------
// Method:      TimedDrive <<constructor>>
// Description: This method creates/intializes the object.
//--------------------------------------------------------------------
TimedDrive::TimedDrive
(
    float   time            // <I> - time to drive in seconds
) : RunMotorsDrive( 1.0 ),
    m_targetLoopCount( 0 ),
    m_loopCount( 0 )
{
    CalculateLoopCount( time );
    Init();
}


//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void TimedDrive::Init()
{
    SetBrakeMode();
    ChangeSpeed( 1.0 );
}

//--------------------------------------------------------------------
// Method:      CalculateLoopCount
// Description: This method calculates the number of loops that needed
//              to be run to meet the time criteria.  It then sets
//              the m_targetLoopCount attribute and initializes the
//              m_loopCount to 0.
// Returns:     void
//--------------------------------------------------------------------
void TimedDrive::CalculateLoopCount
(
    float   time            // <I> - time to drive in seconds
)
{
    // TODO:    Calculate m_targetLoopCount from time.  How can we
    //          convert time to loop count?  Start the motors at
    //          full speed using the ChangeSpeed method of the parent
    //          class.
    //                  Are there other ways to do this?
    //                  What are they?
    //                  What are the advantages/disadvantages or each option?
}

//--------------------------------------------------------------------
// Method:      HasTarget
// Description: This indicates if this drive mode has a target
// Returns:     true = has a target (time)
//--------------------------------------------------------------------
bool TimedDrive::HasTarget() const
{
    return false;
}


//--------------------------------------------------------------------
// Method:      SetTarget
// Description: This sets the target for the drive class.
// Returns:     void
//--------------------------------------------------------------------
void TimedDrive::SetTarget
(
    float   time
)
{
    CalculateLoopCount( time );
}


//--------------------------------------------------------------------
// Method:      DrivePeriodic
// Description: This method will be called during the periodic loop
//              to drive the robot for a specified period of time.
// Returns:     true  = reached the specified time
//              false = hasn't reached the specified time
//--------------------------------------------------------------------
bool TimedDrive::DrivePeriodic() const
{
    // TODO:    increment the loop count and compare it to the target
    //          if the target has been reached stop the motors using the
    //          the ChangeSpeed method of the parent class.  Otherwise,
    //          let the motors keep running.
    //
    //          Set the return value based one whether the target loop count
    //          has been reached yet or not.
    //
    //          NOTE:  there are multiple ways to approach stopping the motors,
    //                 what are they?
    return false;
}



//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* TimedDrive::GetIdentifier() const
{
    return "Timed Drive";
}

